@@ -355,7 +355,7 @@ sub _check ( $self, $connect, $cb ) {
             }
         }
         else {
-            # cache test result only if no caoonect error
+            # cache test result only if no connect error
             if ( !$self->{connect_error} ) {
 
                 # reset connect errors counter
@@ -450,7 +450,7 @@ sub _test_connection ( $self, $connect, $proxy_type, $cb ) {
         timeout                     => $PROXY_TEST_TIMEOUT,
         persistent                  => 0,
         proxy                       => $self,
-        proxy_type                  => $proxy_type,                     # connect to proxy without waitinf for the slot
+        proxy_type                  => $proxy_type,                     # connect to proxy without waiting for the slot
         _proxy_keep_thread_on_error => 1,                               # do not finish proxy thread automatically on handle destroy
         on_error                    => sub ( $h, $fatal, $message ) {
             $cb->(undef);
@@ -513,10 +513,10 @@ sub _test_scheme_httpx ( $self, $scheme, $h, $proxy_type, $cb ) {
         my $auth_header = $self->userinfo ? q[Proxy-Authorization: Basic ] . $self->userinfo_b64 . $CRLF : q[];
 
         if ( $scheme eq 'http' ) {
-            $h->push_write(qq[GET http://www.google.com/favicon.ico HTTP/1.0${CRLF}${auth_header}${CRLF}]);
+            $h->push_write(qq[GET http://www.google.com/favicon.ico HTTP/1.0${CRLF}Host:www.google.com${CRLF}${auth_header}${CRLF}]);
         }
         else {
-            $h->push_write(qq[GET https://www.google.com/favicon.ico HTTP/1.0${CRLF}${auth_header}${CRLF}]);
+            $h->push_write(qq[GET https://www.google.com/favicon.ico HTTP/1.0${CRLF}Host:www.google.com${CRLF}${auth_header}${CRLF}]);
         }
     }
     else {
